pub struct ArrayQueue<T> { /* private fields */ }Expand description
A bounded multi-producer multi-consumer queue.
Implementations
Sourceimpl<T> ArrayQueue<T>
impl<T> ArrayQueue<T>
Sourcepub fn new(cap: usize) -> ArrayQueue<T>
pub fn new(cap: usize) -> ArrayQueue<T>
Creates a new bounded queue with the given capacity.
The capacity will be rounded up to the next power of two.