Disruptor

Struct Disruptor 

pub struct Disruptor<T> { /* private fields */ }
Disruptor Facade.

Implementations

Source

impl<T: Send + Sync + 'static> Disruptor<T>

pub fn builder<F>(factory: F) -> DisruptorBuilder<T, F>
where F: Fn() -> T,

Creates a new builder for the Disruptor.

pub fn handle_events_with<H: EventHandler<T> + 'static>( &mut self, handler: H, ) -> &mut Self

Registers an event handler.

pub fn start(self) -> Producer<T>

Starts the Disruptor and returns a Producer.

Consumer threads are spawned for each registered handler. When the returned Producer is dropped, it alerts all consumer barriers and joins the threads, ensuring a clean shutdown.